<?php
function _addComment(&$tof,$vars) {
	if ($vars['Comment'] != "") {
		global $_SERVER['REMOTE_ADDR'];
		$comment = array('CommentID' => time(),
						 'PictureID' => $vars['PictureID'],
						 'Comment' => $vars['Comment'],
						 'IP' => $REMOTE_ADDR,
						 'UserID' => $tof->uid);
		addComment($tof,$comment);
	}
}

function addComment(&$tof,$comment) {
	$tof->ct->addComment($comment);
	/* Notify the owner of the picture if he wants to */
	$picture = $tof->ct->getPicture($comment['PictureID']);
	if (is_array($picture)) {
		$user = $tof->ct->getUser($picture['Owner']);
		if (is_array($user) && $user['NotifyComment']=='t' 
			&& $user['Email']!="") {
			$text = sprintf(_("There's a new comment for your picture %s\n"),
							$tof->fullSelfURL()."?PictureID=".$comment['PictureID']).
				 $comment['Comment'];
			mail($user['Email'],_("New comment for your picture"),$text);
		}
	}
}
?>